/*
 * Dynamic Bezier curves on canvas
 * By Jacek Cichoń, http://prac.im.pwr.wroc.pl/~cichon/
 * This code can be used without restriction.
 */

var points = [], //points on the "multi Bezier curve"
	cWidth,
	cHeight,
	dPoint,
	otoczka = true,
	linie   = true,
	punkty  = true;

var N = 7; // number od "main" controll points

var canvas, ctx,
	radius = 5,
	radius2 = 2 * radius * radius,
	drag = null; //index of dragged point

function Draw() {
	var i;
	ctx.fillStyle = "#ff0";
	ctx.clearRect(0, 0, cWidth, cHeight);
	ctx.strokeStyle = "#000000";
	ctx.lineWidth = 3;
	ctx.globalAlpha = 1;
	if (otoczka) {
		for (i = 0; i <= N - 2; i++) {
			ctx.beginPath();
			ctx.moveTo(points[3 * i].x, points[3 * i].y);
			ctx.lineTo(points[3 * i + 1].x, points[3 * i + 1].y);
			ctx.lineTo(points[3 * i + 2].x, points[3 * i + 2].y);
			ctx.lineTo(points[3 * i + 3].x, points[3 * i + 3].y);
			ctx.fill();

			ctx.beginPath();
			ctx.moveTo(points[3 * i].x, points[3 * i].y);
			ctx.lineTo(points[3 * i + 2].x, points[3 * i + 2].y);
			ctx.lineTo(points[3 * i + 1].x, points[3 * i + 1].y);
			ctx.lineTo(points[3 * i + 3].x, points[3 * i + 3].y);
			ctx.fill();
		}
	}
	ctx.globalAlpha = 1;
	ctx.beginPath();
	ctx.moveTo(points[0].x, points[0].y);
	for (i = 0; i <= N - 2; i++) {
		ctx.bezierCurveTo(points[3 * i + 1].x, points[3 * i + 1].y,
			points[3 * i + 2].x, points[3 * i + 2].y,
			points[3 * i + 3].x, points[3 * i + 3].y);
	}
	ctx.stroke();

	// "main" points
	ctx.fillStyle = "#ff0000";
	ctx.lineWidth = 1;
	for (i = 0; i <= N - 1; i++) {
		ctx.beginPath();
		ctx.arc(points[3 * i].x, points[3 * i].y, radius, 0, 2 * Math.PI);
		ctx.fill();
	}

	if (punkty) {
		ctx.fillStyle = "#555";
		for (i = 0; i <= N - 2; i++) {
			ctx.beginPath();
			ctx.arc(points[3 * i + 1].x, points[3 * i + 1].y, radius, 0, 2 * Math.PI);
			ctx.fill();
		}

		for (i = 0; i <= N - 2; i++) {
			ctx.fillRect(points[3 * i + 2].x - radius, points[3 * i + 2].y - radius, 2 * radius, 2 * radius);
		}
	}

	if (linie) {
		ctx.strokeStyle = "#000";
		ctx.beginPath();
		for (i = 0; i <= N - 2; i++) {
			ctx.moveTo(points[3 * i].x, points[3 * i].y);
			ctx.lineTo(points[3 * i + 1].x, points[3 * i + 1].y);
			ctx.moveTo(points[3 * i + 2].x, points[3 * i + 2].y);
			ctx.lineTo(points[3 * i + 3].x, points[3 * i + 3].y);
		}
		ctx.stroke();
	}
}

// event parser
function MousePos(event) {
	//event = (event ? event : window.event);
	event = event || window.event;
	return {
		x : event.pageX - canvas.offsetLeft,
		y : event.pageY - canvas.offsetTop
	};
}

// start dragging
function DragStart(e) {
	e = MousePos(e);
	var dx,
	dy,
	L = points.length,
	i;
	for (i = 0; i < L; i++) {
		dx = points[i].x - e.x;
		dy = points[i].y - e.y;
		if ((dx * dx) + (dy * dy) < radius2) {
			drag = i;
			dPoint = e;
			canvas.style.cursor = "move";
			return;
		}
	}
}

// dragging
function Dragging(e) {
	if (drag !== null) {
		e = MousePos(e);
		points[drag].x += e.x - dPoint.x;
		points[drag].y += e.y - dPoint.y;
		dPoint = e;
		Draw();
	}
}

// end dragging
function DragEnd(e) {
	drag = null;
	canvas.style.cursor = "default";
	Draw();
}

function Init() {
	canvas  = document.getElementById("canvas");
	cWidth  = canvas.width;
	cHeight = canvas.height;
	var sY  = cHeight / 2;
	var dX  = cWidth / (N + 1);

	ctx = canvas.getContext("2d");

	ctx.lineCap  = 'round';
	ctx.lineJoin = 'round';

	// event handlers
	canvas.onmousedown = DragStart;
	canvas.onmousemove = Dragging;
	canvas.onmouseup   = DragEnd;
	
	points.push({
		x : dX,
		y : sY
	});
	points.push({
		x : dX,
		y : 0.5 * sY
	}); //control point

	var up = true;
	for (var i = 2; i <= N - 1; i++) {
		points.push({
			x : i * dX,
			y : (up ? 0.5 : 1.5) * sY
		});
		points.push({
			x : i * dX,
			y : sY
		});
		points.push({
			x : i * dX,
			y : (up ? 1.5 : 0.5) * sY
		});
		up = !up;
	}
	points.push({
		x : N * dX,
		y : (up ? 0.5 : 1.5) * sY
	});
	points.push({
		x : N * dX,
		y : sY
	});
	Draw();
}

window.onload = Init();